==> zio-aws-kms_2.13-5.17.104.12-sources.jar: zio/aws/kms/model/GenerateDataKeyPairRequest.scala <==
package zio.aws.kms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kms.model.primitives.{
  GrantTokenType,
  KeyIdType,
  EncryptionContextValue,
  EncryptionContextKey
}
import scala.jdk.CollectionConverters._
final case class GenerateDataKeyPairRequest(
    encryptionContext: Option[
      Map[EncryptionContextKey, EncryptionContextValue]
    ] = None,
    keyId: KeyIdType,
    keyPairSpec: zio.aws.kms.model.DataKeyPairSpec,
    grantTokens: Option[Iterable[GrantTokenType]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest = {
    import GenerateDataKeyPairRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
      .builder()
      .optionallyWith(
        encryptionContext.map(value =>
          value
            .map({ case (key, value) =>
              (EncryptionContextKey.unwrap(
                key
              ): java.lang.String) -> (EncryptionContextValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.encryptionContext)
      .keyId(KeyIdType.unwrap(keyId): java.lang.String)
      .keyPairSpec(keyPairSpec.unwrap)
      .optionallyWith(
        grantTokens.map(value =>
          value.map { item =>
            GrantTokenType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.grantTokens)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.GenerateDataKeyPairRequest.ReadOnly =
    zio.aws.kms.model.GenerateDataKeyPairRequest.wrap(buildAwsValue())
}
object GenerateDataKeyPairRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.GenerateDataKeyPairRequest =
      zio.aws.kms.model.GenerateDataKeyPairRequest(
        encryptionContext.map(value => value),
        keyId,
        keyPairSpec,
        grantTokens.map(value => value)
      )
    def encryptionContext
        : Option[Map[EncryptionContextKey, EncryptionContextValue]]
    def keyId: KeyIdType
    def keyPairSpec: zio.aws.kms.model.DataKeyPairSpec
    def grantTokens: Option[List[GrantTokenType]]
    def getEncryptionContext: ZIO[Any, AwsError, Map[
      EncryptionContextKey,
      EncryptionContextValue
    ]] = AwsError.unwrapOptionField("encryptionContext", encryptionContext)
    def getKeyId: ZIO[Any, Nothing, KeyIdType] = ZIO.succeed(keyId)
    def getKeyPairSpec: ZIO[Any, Nothing, zio.aws.kms.model.DataKeyPairSpec] =
      ZIO.succeed(keyPairSpec)
    def getGrantTokens: ZIO[Any, AwsError, List[GrantTokenType]] =
      AwsError.unwrapOptionField("grantTokens", grantTokens)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
  ) extends zio.aws.kms.model.GenerateDataKeyPairRequest.ReadOnly {
    override val encryptionContext
        : Option[Map[EncryptionContextKey, EncryptionContextValue]] = scala
      .Option(impl.encryptionContext())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.kms.model.primitives.EncryptionContextKey(
              key
            ) -> zio.aws.kms.model.primitives.EncryptionContextValue(value)
          })
          .toMap
      )
    override val keyId: KeyIdType =
      zio.aws.kms.model.primitives.KeyIdType(impl.keyId())
    override val keyPairSpec: zio.aws.kms.model.DataKeyPairSpec =
      zio.aws.kms.model.DataKeyPairSpec.wrap(impl.keyPairSpec())
    override val grantTokens: Option[List[GrantTokenType]] = scala
      .Option(impl.grantTokens())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kms.model.primitives.GrantTokenType(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
  ): zio.aws.kms.model.GenerateDataKeyPairRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kms_2.13-5.17.174.1-sources.jar: zio/aws/kms/model/GenerateDataKeyPairRequest.scala <==
package zio.aws.kms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kms.model.primitives.{
  GrantTokenType,
  KeyIdType,
  EncryptionContextValue,
  EncryptionContextKey
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GenerateDataKeyPairRequest(
    encryptionContext: Optional[
      Map[EncryptionContextKey, EncryptionContextValue]
    ] = Optional.Absent,
    keyId: KeyIdType,
    keyPairSpec: zio.aws.kms.model.DataKeyPairSpec,
    grantTokens: Optional[Iterable[GrantTokenType]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest = {
    import GenerateDataKeyPairRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
      .builder()
      .optionallyWith(
        encryptionContext.map(value =>
          value
            .map({ case (key, value) =>
              (EncryptionContextKey.unwrap(
                key
              ): java.lang.String) -> (EncryptionContextValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.encryptionContext)
      .keyId(KeyIdType.unwrap(keyId): java.lang.String)
      .keyPairSpec(keyPairSpec.unwrap)
      .optionallyWith(
        grantTokens.map(value =>
          value.map { item =>
            GrantTokenType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.grantTokens)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.GenerateDataKeyPairRequest.ReadOnly =
    zio.aws.kms.model.GenerateDataKeyPairRequest.wrap(buildAwsValue())
}
object GenerateDataKeyPairRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.GenerateDataKeyPairRequest =
      zio.aws.kms.model.GenerateDataKeyPairRequest(
        encryptionContext.map(value => value),
        keyId,
        keyPairSpec,
        grantTokens.map(value => value)
      )
    def encryptionContext
        : Optional[Map[EncryptionContextKey, EncryptionContextValue]]
    def keyId: KeyIdType
    def keyPairSpec: zio.aws.kms.model.DataKeyPairSpec
    def grantTokens: Optional[List[GrantTokenType]]
    def getEncryptionContext: ZIO[Any, AwsError, Map[
      EncryptionContextKey,
      EncryptionContextValue
    ]] = AwsError.unwrapOptionField("encryptionContext", encryptionContext)
    def getKeyId: ZIO[Any, Nothing, KeyIdType] = ZIO.succeed(keyId)
    def getKeyPairSpec: ZIO[Any, Nothing, zio.aws.kms.model.DataKeyPairSpec] =
      ZIO.succeed(keyPairSpec)
    def getGrantTokens: ZIO[Any, AwsError, List[GrantTokenType]] =
      AwsError.unwrapOptionField("grantTokens", grantTokens)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
  ) extends zio.aws.kms.model.GenerateDataKeyPairRequest.ReadOnly {
    override val encryptionContext
        : Optional[Map[EncryptionContextKey, EncryptionContextValue]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionContext())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.kms.model.primitives.EncryptionContextKey(
                key
              ) -> zio.aws.kms.model.primitives.EncryptionContextValue(value)
            })
            .toMap
        )
    override val keyId: KeyIdType =
      zio.aws.kms.model.primitives.KeyIdType(impl.keyId())
    override val keyPairSpec: zio.aws.kms.model.DataKeyPairSpec =
      zio.aws.kms.model.DataKeyPairSpec.wrap(impl.keyPairSpec())
    override val grantTokens: Optional[List[GrantTokenType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.grantTokens())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.kms.model.primitives.GrantTokenType(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyPairRequest
  ): zio.aws.kms.model.GenerateDataKeyPairRequest.ReadOnly = new Wrapper(impl)
}
